import ColHeader from '@/components/col-header'
import ColResult from '@/components/col-result'
import ColSearch from '@/components/col-search'
import request from '@/helpers/request'
import { state } from '@/state'
import { List, Popup, Sticky, Image } from 'vant'
import { defineComponent } from 'vue'
import OrganSearch from '../practice-class/model/organ-search'
import styles from './teacher-elegant.module.less'

import iconTeacher from '@common/images/icon_teacher.png'

export default defineComponent({
  data() {
    return {
      searchStatus: false,
      openStatus: false,
      subjectList: [],
      params: {
        username: '',
        page: 1,
        subjectId: null as any,
        subjectName: ''
      },
      dataShow: true, // 判断是否有数据
      loading: false,
      finished: false,
      list: []
    }
  },
  async mounted() {
    this.params.subjectId = state.user.data?.subjectId || null
    this.params.subjectName = state.user.data?.subjectName || ''
    try {
      const res = await request.get('/api-student/subject/subjectSelect')
      this.subjectList = res.data || []
    } catch {}

    await this.getList()
  },
  methods: {
    async getList() {
      try {
        const params = this.params
        const res = await request.post('/api-student/teacher/stylePage', {
          data: {
            ...params
          }
        })
        console.log(res)
        const result = res.data || {}
        // 处理重复请求数据
        if (this.list.length > 0 && result.pageNo === 1) {
          return
        }
        this.list = this.list.concat(result.rows || [])
        this.finished = result.pageNo >= result.totalPage
        this.params.page = result.pageNo + 1
        this.dataShow = this.list.length > 0

        console.log(this.list)
      } catch {}
    },
    onSort() {
      this.params.page = 1
      this.list = []
      this.dataShow = true // 判断是否有数据
      this.loading = false
      this.finished = false
      this.searchStatus = false
      this.getList()
    },
    onSearch(_search?: any) {
      this.params.username = _search
      this.onSort()
    },
    onDetail(item: any) {
      this.$router.push({
        path: '/teacherHome',
        query: {
          teacherId: item.userId
        }
      })
    }
  },
  render() {
    return (
      <div class={styles['teacher-elegant']}>
        <Sticky offsetTop={0}>
          <ColHeader
            class={styles.classHeader}
            border={false}
            background="transparent"
            isFixed={false}
          />
          <ColSearch
            placeholder="请输入老师名称"
            showAction
            onSearch={this.onSearch}
            onFilter={() => {
              this.searchStatus = !this.searchStatus
              this.openStatus = !this.openStatus
            }}
          />
          <div class={styles.searchContainer}>
            <div class={[styles.searchItem, styles.searchFollow]}>
              <p class={styles.title}>我的关注</p>
              <p class={styles.content}>老师最新动态</p>
            </div>
            <div class={[styles.searchItem, styles.searchLive]}>
              <p class={styles.title}>直播中</p>
              <p class={styles.content}>互动直播间</p>
            </div>
          </div>
        </Sticky>

        {this.dataShow ? (
          <List
            v-model:loading={this.loading}
            finished={this.finished}
            finishedText=" "
            immediateCheck={false}
            class={[styles.elegant]}
            onLoad={this.getList}
          >
            {this.list.map((item: any) => (
              <div
                class={styles.tedeoItem}
                onClick={() => {
                  this.onDetail(item)
                }}
              >
                {/* <Image class={styles.teCover} fit="cover" src={item.videoUrl} /> */}
                <div class={styles.teCover}>
                  <video
                    width="100%"
                    style={{
                      width: '100%',
                      minHeight: '100%',
                      borderRadius: '4px 4px 0 0',
                      backgroundColor: '#ccc'
                    }}
                  >
                    <source src={item.videoUrl + '#t=1,3'} type="video/mp4" />
                  </video>
                </div>
                <div class={styles.teSection}>
                  <div class={[styles.teTitle, 'van-ellipsis']}>
                    {item.lessonName}
                  </div>
                  <div class={styles.info}>
                    <div class={styles.teUserInfo}>
                      <Image
                        src={item.avatar || iconTeacher}
                        class={styles.teUserLogo}
                      />
                      <span class={[styles.teUserName, 'van-hairline--right']}>
                        {item?.username || `游客${item?.userId || ''}`}
                      </span>
                    </div>
                    <span class={styles.teUserNum}>{item.browse}观看</span>
                  </div>
                </div>
              </div>
            ))}
          </List>
        ) : (
          <ColResult
            btnStatus={false}
            classImgSize="SMALL"
            tips="暂无老师风采"
          />
        )}

        <Popup
          show={this.searchStatus}
          position="bottom"
          round
          closeable
          safe-area-inset-bottom
          onClose={() => (this.searchStatus = false)}
          onClosed={() => (this.openStatus = false)}
        >
          {this.openStatus && (
            <OrganSearch
              subjectList={this.subjectList}
              onSort={this.onSort}
              v-model={this.params.subjectId}
              v-model:subjectName={this.params.subjectName}
            />
          )}
        </Popup>
      </div>
    )
  }
})
